@@ -6,12 +6,11 @@ my $ver = get_qp_version();
    $ver =~ m/^([\d]+)\.(\d+)$/;
 my $new_ver = $1 . '.' . ($2 + 1);
 
-`find lib -name '*.pm' -exec sed -i .bak -e 's/$ver/$new_ver/' {} \;`;
-`find lib -name '*.pm.bak' -delete`;
+`find lib -type f -name '*.pm' -exec sed -i .bak -e 's/$ver/$new_ver/' {} \\\;`;
+`find lib -type f -name '*.pm.bak' -delete`;
 
 sub get_qp_version {
-    my $rvfile = get_file_contents('lib/Mail/Toaster.pm')
-        or return;
+    my $rvfile = get_file_contents('lib/Mail/Toaster.pm') or die "failed to get VERSION\n";
     my ($ver_line) = grep { $_ =~ /^(?:my|our) \$VERSION/ } @$rvfile;
     my ($ver) = $ver_line =~ /(?:"|')([0-9\.]+)(?:"|')/;
     return $ver;
